@@ -344,6 +344,7 @@ class CloudApi(object):
                     source_stream,
                     destination_resource,
                     request_config,
+                    source_resource=None,
                     serialization_data=None,
                     tracker_callback=None,
                     upload_strategy=UploadStrategy.SIMPLE):
@@ -355,6 +356,8 @@ class CloudApi(object):
         Contains the correct metadata to upload.
       request_config (RequestConfig): Object containing general API function
         arguments. Subclasses for specific cloud providers are available.
+      source_resource (resource_reference.FileObjectResource|None):
+        Contains the source StorageUrl. Can be None if source is pure stream.
       serialization_data (dict): API-specific data needed to resume an upload.
         Only used with UploadStrategy.RESUMABLE.
       tracker_callback (Callable[[dict], None]): Function that writes a tracker
