@@ -890,10 +890,12 @@ class GcsApi(cloud_api.CloudApi):
                     source_stream,
                     destination_resource,
                     request_config,
+                    source_resource=None,
                     serialization_data=None,
                     tracker_callback=None,
                     upload_strategy=cloud_api.UploadStrategy.SIMPLE):
     """See CloudApi class for function doc strings."""
+    del source_resource  # TODO(b/222110136): Use for gzip-transfer decision.
     if self._upload_http_client is None:
       self._upload_http_client = transports.GetApitoolsTransport(
           redact_request_body_reason=(
