@@ -35,12 +35,6 @@ class PrivateCloudsClient(util.VmwareClientBase):
         name=resource.RelativeName())
 
     response = self.service.Get(request)
-    if response.vcenter is not None:
-      response.vcenter.fdqn = None
-    if response.hcx is not None:
-      response.hcx.fdqn = None
-    if response.nsx is not None:
-      response.nsx.fdqn = None
     return response
 
   def Create(self,
