@@ -401,14 +401,14 @@ def AddRuntimeFlag(parser):
           - `nodejs10`: Node.js 10
           - `nodejs12`: Node.js 12
           - `nodejs14`: Node.js 14
-          - `nodejs16`: Node.js 16 (preview)
+          - `nodejs16`: Node.js 16
           - `php74`: PHP 7.4
           - `python37`: Python 3.7
           - `python38`: Python 3.8
           - `python39`: Python 3.9
           - `go111`: Go 1.11
           - `go113`: Go 1.13
-          - `go116`: Go 1.16 (preview)
+          - `go116`: Go 1.16
           - `java11`: Java 11
           - `java17`: Java 17 (preview)
           - `dotnet3`: .NET Framework 3
