@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 """Wrapper for interacting with speech API."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
 
 import os
@@ -30,6 +31,11 @@ SPEECH_API = 'speech'
 SPEECH_API_VERSION = 'v1'
 
 
+OUTPUT_ERROR_MESSAGE = ('[{}] is not a valid format for result output. Must be '
+                        'a Google Cloud Storage URI '
+                        '(format: gs://bucket/file).')
+
+
 class Error(exceptions.Error):
   """Exceptions for this module."""
 
@@ -38,6 +44,27 @@ class AudioException(Error):
   """Raised if audio is not found."""
 
 
+class UriFormatError(Error):
+  """Error if the specified URI is invalid."""
+
+
+def GetRecognitionAudioFromPath(path, version):
+  """Determine whether path to audio is local, set RecognitionAudio message."""
+  messages = apis.GetMessagesModule(SPEECH_API, version)
+  audio = messages.RecognitionAudio()
+
+  if os.path.isfile(path):
+    audio.content = files.ReadBinaryFileContents(path)
+  elif storage_util.ObjectReference.IsStorageUrl(path):
+    audio.uri = path
+  else:
+    raise AudioException(
+        'Invalid audio source [{}]. The source must either be a local path '
+        'or a Google Cloud Storage URL (such as gs://bucket/object).'.format(
+            path))
+  return audio
+
+
 def GetAudioHook(version=SPEECH_API_VERSION):
   """Returns a hook to get the RecognitionAudio message for an API version."""
   def GetAudioFromPath(path):
@@ -53,18 +80,22 @@ def GetAudioHook(version=SPEECH_API_VERSION):
     Returns:
       speech_v1_messages.RecognitionAudio, the audio message.
     """
-    messages = apis.GetMessagesModule(SPEECH_API, version)
-    audio = messages.RecognitionAudio()
-
-    if os.path.isfile(path):
-      audio.content = files.ReadBinaryFileContents(path)
-    elif storage_util.ObjectReference.IsStorageUrl(path):
-      audio.uri = path
-    else:
-      raise AudioException(
-          'Invalid audio source [{}]. The source must either be a local path '
-          'or a Google Cloud Storage URL (such as gs://bucket/object).'
-          .format(path))
-
-    return audio
+    return GetRecognitionAudioFromPath(path, version)
   return GetAudioFromPath
+
+
+def ValidateOutputUri(output_uri):
+  """Validates given output URI against validator function.
+
+  Args:
+    output_uri: str, the output URI for the analysis.
+
+  Raises:
+    UriFormatError: if the URI is not valid.
+
+  Returns:
+    str, The same output_uri.
+  """
+  if output_uri and not storage_util.ObjectReference.IsStorageUrl(output_uri):
+    raise UriFormatError(OUTPUT_ERROR_MESSAGE.format(output_uri))
+  return output_uri
