@@ -12,7 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """Command to submit a specified Batch job."""
 
 from __future__ import absolute_import
@@ -22,9 +21,10 @@ from __future__ import unicode_literals
 from googlecloudsdk.api_lib.batch import jobs
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.batch import resource_args
+from googlecloudsdk.core import log
 
 
-class Submit(base.CreateCommand):
+class Submit(base.Command):
   """Submit a Batch job.
 
   This command can fail for the following reasons:
@@ -43,9 +43,7 @@ class Submit(base.CreateCommand):
     resource_args.AddJobResourceArgs(parser)
 
     parser.add_argument(
-        '--config',
-        required=True,
-        help='''The config file of a job.''')
+        '--config', required=True, help='The config file of a job.')
 
   def Run(self, args):
     job_ref = args.CONCEPTS.job.Parse()
@@ -53,4 +51,8 @@ class Submit(base.CreateCommand):
     location_ref = job_ref.Parent()
 
     client = jobs.JobsClient()
-    return client.Create(job_id, location_ref, args.config)
+
+    resp = client.Create(job_id, location_ref, args.config)
+    log.status.Print(
+        'Job {jobName} was successfully submitted.'.format(jobName=resp.uid))
+    return resp
