@@ -34,7 +34,7 @@ auto_flags = [
     'authenticatorsecurity',
     'databaseencryption',
     'bootdiskkms',
-    'network_tags',
+    'autoprovisioning_network_tags',
 ]
 
 # Change default flag values in create-auto
@@ -55,7 +55,6 @@ def AddAutoFlags(parser):
   """Adds flags that are not same in create."""
   flags.AddLoggingFlag(parser, autopilot=True)
   flags.AddMonitoringFlag(parser, autopilot=True)
-  flags.AddNetworkTagsCreate(parser)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
