@@ -20,7 +20,7 @@ from __future__ import unicode_literals
 
 import sys
 from googlecloudsdk.command_lib.anthos.common import file_parsers
-from googlecloudsdk.command_lib.container.hub.features import base
+from googlecloudsdk.command_lib.container.fleet.features import base
 from googlecloudsdk.core import exceptions
 from googlecloudsdk.core import log
 from googlecloudsdk.core.console import console_io
