@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2021 Google LLC. All Rights Reserved.
+# Copyright 2022 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,11 +22,11 @@ import textwrap
 
 from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.calliope import base
-from googlecloudsdk.command_lib.container.hub import agent_util
-from googlecloudsdk.command_lib.container.hub import api_util
-from googlecloudsdk.command_lib.container.hub import exclusivity_util
-from googlecloudsdk.command_lib.container.hub import kube_util
-from googlecloudsdk.command_lib.container.hub import util as hub_util
+from googlecloudsdk.command_lib.container.fleet import agent_util
+from googlecloudsdk.command_lib.container.fleet import api_util
+from googlecloudsdk.command_lib.container.fleet import exclusivity_util
+from googlecloudsdk.command_lib.container.fleet import kube_util
+from googlecloudsdk.command_lib.container.fleet import util as hub_util
 from googlecloudsdk.command_lib.util.apis import arg_utils
 from googlecloudsdk.core import exceptions
 from googlecloudsdk.core import log
